import { CfnBucket, CfnBucketPolicy } from "@aws-cdk/aws-s3";
import { BaseComplianceChecker } from "./compliance-checker";
export interface S3Config {
    serverSideEncryption?: boolean;
    ssl?: boolean;
}
export declare class S3ComplianceChecker extends BaseComplianceChecker<CfnBucket | CfnBucketPolicy> {
    constructor(config: S3Config);
    checkCompliance(node: CfnBucket | CfnBucketPolicy): void;
    /**
     * [S3.4] S3 buckets should have server-side encryption enabled
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-s3-4
     */
    private checkServerSideEncryption;
    /**
     * [S3.5] S3 buckets should require requests to use Secure Socket Layer
     * Ref: https://docs.aws.amazon.com/securityhub/latest/userguide/securityhub-standards-fsbp-controls.html#fsbp-s3-5
     */
    private checkSSL;
}
